/*
** Module   : dc.cmd
**
** Abstract : Change directory via alias
**
** Parameters: dc alias
**
** Copyright 2003 PillarSoft
** All Rights Reserved
**
*/
parse arg Option

/* Initialize things */
Call Init
Call Banner

/* Check our "Option," If not '', '?' or */
/* 'ADD' we will look for it in the list */

if Option = '?'   then Call SyntaxHelp
if Option = ''    then Call SyntaxHelp
if Option = 'ADD' then Call AddDirectory
else do
  if DList.0 > 0 then do
    do x = 1 to DList.0
      if Word(Dlist.x.name, 1) = Option then
         Call Directory DList.x.path
    end
  end
  else Say 'No directories are set'
end

Exit

/* *********************************************************
** Subroutines
** *********************************************************
** Banner
** Exists()
** Init
** AddDirectory
** Listing()
** PathExists
** Syntaxhelp
** ShowHtmlHelp
**
*/

/**********************************************************/
/* Banner - Show ProgramName And Copyright Info           */
/**********************************************************/
Banner:

'@cls'
Say Adcolor,
 || 'ͻ'
Say '        Directory Change (dc) v1.0         '
Say 'Ķ'
Say '     Copyright 2001 - 2003, PillarSoft     '
Say '           All Rights Reserved             '
Say 'ͼ'
Say Default

Return


/**********************************************************/
/* Exists - Check If A File Exists                        */
/*                                                        */
/* 0 = File Does Not Exist                                */
/* 1 = File Exists                                        */
/**********************************************************/
Exists:  Procedure
Parse Arg Value

Rc = Sysfiletree(value,'list','fo')
If List.0 > 0 Then Return 1
Else Return 0


/**********************************************************/
/* Init - Initialize Variables And Load Libraries         */
/*                                                        */
/* If There Are No Commandline Args, We Ask What File To  */
/**********************************************************/
Init:

'@echo Off'
'@ansi On'

/* Load Rexxutil Functions */
If Rxfuncquery('sysloadfuncs') Then Do
  Call Rxfuncadd 'sysloadfuncs','rexxutil','sysloadfuncs'
  Call Sysloadfuncs
End

/* Get The Working Directory And Build The Logfile Name   */
Parse Source . . Thisprogram
Thisdir      = Filespec('d',thisprogram)||Filespec('p',thisprogram)
Logfile      = Thisdir||'dc.log'
HelpFile     = Thisdir||'dc.htm'
DataFile     = Thisdir||'dc.dat'
Option       = Translate(Strip(Option))

/* Set some variables */
Crlf         = '0d0a'x
Default      = '1b'x||'[0m' /* White On Black */
Bold         = '1b'x||'[1m'
Yellow       = '1b'x||'[1;33m'
Adcolor      = '1b'x||'[44;37m' /* White On Blue */

/* Read directory alias's into DList.x */
/* If alias's do not exist, initialize */
/* the stem to 0 entries.              */

if exists(DataFile) then do
  x = 0
  Do While Lines(DataFile)
    value = LineIn(DataFile)
    x = x + 1
    parse var value DList.x.name DList.x.path
    DList.0 = x
  End
  rc = Stream(DataFile,'c','close')
end
else DList.0 = 0

Return


/**********************************************************/
/* AddDirectory - Add a directory to cdir.dat             */
/**********************************************************/
AddDirectory:

/* Check if this path already has an alias */
/* Display the current directory name and  */
/* ask the user to enter an alias.         */

Call PathExists
Say Directory()||crlf
Call CharOut, Bold||'Enter alias: '||Default
Pull answer .

if answer <> '' then do
  /* Check alias against listing */
  Lx = Listing(answer)
  /* 0 means the listing does not exist */
  /* Add it to the database             */
  if Lx < 1 then do
    Call LineOut DataFile, Answer Directory()
    Call Stream DataFile, 'C', 'Close'
    Say 'Added: '||Bold||Answer Directory()||Default||' to database.'
  end
  else do
    /* To get here the alias must already */
    /* exist. Ask user for a new alias.   */
    Say crlf||Bold||'Existing alias: '||Default||answer
    Say Bold||'Pointing to: '||Default||DList.Lx.path||crlf
    Say Yellow||'<'||Default||'Enter'||Yellow||'>'||Default||' to try another alias or press '||Yellow||'['||Default||'Q'||Yellow||']'||Default||' to quit.'
    pull answer
    if answer = 'Q' then exit
    Call Banner
    Call AddDirectory
  end
end
else Say 'No entry, aborting...'||crlf

Exit


/**********************************************************/
/* Listing - Check if listing exists                      */
/**********************************************************/
Listing:
parse arg value

RetValue = 0
if DList.0 > 0 then do
  do x = 1 to DList.0
    /* Path exists, fork program */
    if Thisdir = DList.x.path then Call PathExists x
    /* Alias exists, return stem value */
    if value   = DList.x.name then RetValue = x
  end
end

return RetValue


/**********************************************************/
/* PathExists - If path listing already exists... exit    */
/**********************************************************/
PathExists:

if DList.0 > 0 then do
  do x = 1 to DList.0
    if Thisdir = DList.x.path||'\' then do
      Say 'Path already exists under the alias:' DList.x.name||crlf
      exit
    end
  end
end

return


/**********************************************************/
/* Syntaxhelp - Display Command Line Parameters           */
/**********************************************************/
Syntaxhelp:

Say Bold||' Syntax:'||Default
Say '   dc alias'|| crlf
Say Bold||'Example:'||Default
Say '   dc tcpip'
Say '   dc netscape'|| crlf

Say ' [' ||Yellow||'H'||Default||']elp, use ['||Yellow||'D'||Default||']efault browser or any other key to exit.'
Pull Answer
If Answer = 'H' | Answer = 'D' then Call ShowHtmlHelp Answer

exit 0

/****************************************************************/
/* ShowHtmlHelp - Opens Netscape or WebExplorer to rt.html      */
/****************************************************************/
ShowHtmlHelp:
parse arg HelpType

if HelpType <> 'D' then do /* Search for WebX  or slower :-) */
  Browser = SysSearchPath('PATH','explore.exe')
  if Browser = '' then Browser = SysSearchPath('PATH','netscape.exe')
  if Browser = '' then Browser = SysSearchPath('PATH','os2web.exe')
  if Browser = '' then Browser = SysSearchPath('PATH','mozilla.exe')
  if Browser = '' then Browser = SysSearchPath('PATH','opera.exe')
  if Browser = '' then Browser = SysSearchPath('PATH','soffice.exe')
  if Browser <> '' then address cmd Browser HelpFile
  else do
    rc = SysSetObjectData(HelpFile,'OPEN=DEFAULT;')
    rc = SysSetObjectData(HelpFile,'OPEN=DEFAULT;')
  end
end
else do /* Default */
  /* SysSetObjectData() first time to open  */
  /* SysSetObjectData() twice to give focus */
  rc = SysSetObjectData(HelpFile,'OPEN=DEFAULT;')
  rc = SysSetObjectData(HelpFile,'OPEN=DEFAULT;')
end

exit 0
